<#  
.SYNOPSIS  
	Sets the WindowsEmailAddress field to first.last@smtpdomain.com
.DESCRIPTION  
	This script is for NON EXCHANGE ENVIRONMENTS ONLY. It is designed to set the WindowsEmailAddress field of AD user accounts. It targets a specific OU and all child OUs.
	Note: It removes spaces in names to adhere to RFC 2821
.NOTES  
    Version      	   	: 1.0 - 06-12-2011 - initial version
		Wish list					: better error trapping
    Rights Required		: Rights to update user accounts
    Sched Task Req'd	: No
    Lync Version			: 2010
    Author       			: Pat Richard, Exchange MVP, MCITP (Exchange), MCITP (Lync)
    Email / Blog 			: pat@innervation.com 	http://exchangeblogs.com
    Dedicated Post		: http://www.ucblogs.net/blogs/exchange/archive/2011/06/12/Set-WindowsEmailAddress-field-for-users-in-a-non_2D00_Exchange-environment.aspx
    Disclaimer   			: You running this script means you won't blame me if this breaks your stuff.
    Info Stolen from 	: (Get-Culture)	http://social.technet.microsoft.com/Forums/en/ITCG/thread/ab069b93-cf99-43a2-8226-014ceb0f05c5
    									: (OU picker) http://thepip3r.blogspot.com/2011/06/powershell-guis-active-directory.html
.LINK  
	http://exchangeblogs.com
.EXAMPLE
	.\Set-WindowsEmailAddress.ps1
.INPUTS
	None. You cannot pipe objects to this script.
#>
#Requires -Version 2.0
[string] $FilenameTranscript = $MyInvocation.MyCommand.Name + " " + (hostname)+ " {0:yyyy-MM-dd hh-mmtt}.log" -f (Get-Date)
Start-Transcript -path .\$FilenameTranscript
Clear-Host
$admodules = Get-Module -ListAvailable | ? {$_.Name -eq "ActiveDirectory"}
if ($admodules -and (!(Get-Module ActiveDirectory)){Import-Module ActiveDirectory}else{Write-Host "ActiveDirectory module not available";exit}
[string] $strSMTPDomainName = Read-Host "Please enter an SMTP domain name"

function Add-Node {
	param (
		$selectedNode,
		$name
	)
	$newNode = new-object System.Windows.Forms.TreeNode
 	$newNode.Name = $name
	$newNode.Text = $name
	$selectedNode.Nodes.Add($newNode) | Out-Null
	return $newNode  
}

function Get-NextLevel {
	param (
		$selectedNode,
		$dn
	)

	$OUs = Get-ADObject -Filter 'ObjectClass -eq "organizationalUnit" -or ObjectClass -eq "container"' -SearchScope OneLevel -SearchBase $dn
	
	If ($OUs -eq $null) {
		$node = Add-Node $selectedNode $dn
 	} Else {
		$node = Add-Node $selectedNode $dn

		$OUs | % {
   		Get-NextLevel $node $_.distinguishedName
		}
 	} 
}

function Build-TreeView {
	if ($treeNodes)
	
  {
  	$treeview1.Nodes.remove($treeNodes)
		$form1.Refresh()
  }

	$treeNodes = New-Object System.Windows.Forms.TreeNode
	$treeNodes.text = "Active Directory Hierarchy"
	$treeNodes.Name = "Active Directory Hierarchy"
	$treeNodes.Tag = "root"
	$treeView1.Nodes.Add($treeNodes) | Out-Null

	$treeView1.add_AfterSelect({
	$textbox1.Text = $this.SelectedNode.Name
	})
	
	#Generate Module nodes
  $OUs = Get-NextLevel $treeNodes $strDomainDN

	$treeNodes.Expand()  
}

#Generated Form Function  
function GenerateForm {

	#region Import the Assemblies
  # Import-Module ActiveDirectory
	[reflection.assembly]::loadwithpartialname("System.Windows.Forms") | Out-Null
  [reflection.assembly]::loadwithpartialname("System.Drawing") | Out-Null
  $objIPProperties = [System.Net.NetworkInformation.IPGlobalProperties]::GetIPGlobalProperties()
	$strDNSDomain = $objIPProperties.DomainName.toLower()
	$strDomainDN = $strDNSDomain.toString().split('.'); foreach ($strVal in $strDomainDN) {$strTemp += "dc=$strVal,"}; $strDomainDN = $strTemp.TrimEnd(",").toLower()
	#endregion
  
  #region Generated Form Objects
  $form1 = New-Object System.Windows.Forms.Form
  $treeView1 = New-Object System.Windows.Forms.TreeView
  $label1 = New-Object System.Windows.Forms.Label
 	$textbox1 = New-Object System.Windows.Forms.TextBox
 	$InitialFormWindowState = New-Object System.Windows.Forms.FormWindowState
  #endregion Generated Form Objects
  
  #----------------------------------------------
  #Generated Event Script Blocks
  #----------------------------------------------
  $button1_OnClick=
  {
  $form1.Close()
  
  }
  
  $OnLoadForm_StateCorrection=
  {Build-TreeView
  }
	
	#----------------------------------------------
  #region Generated Form Code
  $form1.Text = "Select source OU"
 	$form1.Name = "form1"
 	$form1.DataBindings.DefaultDataSourceUpdateMode = 0
  $form1.ClientSize = New-Object System.Drawing.Size(400,500)
  
  $treeView1.Size = New-Object System.Drawing.Size(350,375)
 	$treeView1.Name = "treeView1"
 	$treeView1.Location = New-Object System.Drawing.Size(15,15)
 	$treeView1.DataBindings.DefaultDataSourceUpdateMode = 0
  $treeView1.TabIndex = 0
  $form1.Controls.Add($treeView1)
 
 	$label1.Name = "label1"
 	$label1.Location = New-Object System.Drawing.Size(15,400)
 	$label1.Size = New-Object System.Drawing.Size(350,20)
 	$label1.Text = "Selected OU:"
	$form1.Controls.Add($label1)
  
  $textbox1.Name = "textbox1"
 	$textbox1.Location = New-Object System.Drawing.Size(15,425)
 	$textbox1.Size = New-Object System.Drawing.Size(350,20)
 	$textbox1.Text = ""
	$form1.Controls.Add($textbox1)

  $OKButton = New-Object System.Windows.Forms.Button
	$OKButton.Location = New-Object System.Drawing.Size(290,460)
	$OKButton.Size = New-Object System.Drawing.Size(75,23)
	$OKButton.Text = "OK"
	$OKButton.Add_Click({$global:ou=$textbox1.text;$form1.Close()})
	$form1.Controls.Add($OKButton)
	
	#endregion Generated Form Code
  
  #Save the initial state of the form
  $InitialFormWindowState = $form1.WindowState
  #Init the OnLoad event to correct the initial state of the form
  $form1.add_Load($OnLoadForm_StateCorrection)
  #Show the Form
  $form1.ShowDialog()| Out-Null

} #End Function

#Call the Function  
GenerateForm
if ($ou){
	[object] $objUsers = Get-AdUser -filter * | ? {$_.DistinguishedName -match $ou}
	foreach ($objUser in $objUsers){
		[string] $strEmail = ((Get-Culture).TextInfo.ToTitleCase($objUser.GivenName.ToLower()).replace(" ","")) + "." + ((Get-Culture).TextInfo.ToTitleCase($objUser.Surname.ToLower()).replace(" ","")) + "@" + $strSMTPDomainName
		[string] $strSam = $objuser.samaccountname
		write-host $objUser.samaccountname -nonewline
		write-host " ($strEmail)" -foregroundcolor green
		Set-AdUser $strSam -emailaddress $strEmail
	}

	Write-Host "`n`nDone" -foregroundcolor green
	Remove-Variable strsmtpdomainname
	Remove-Variable objusers
}

Stop-Transcript